<?php
	/** @var FreshRSS_View $this */
	FreshRSS::preLayout();
?>
<!DOCTYPE html>
<html lang="<?= FreshRSS_Context::$user_conf->language ?>" xml:lang="<?= FreshRSS_Context::$user_conf->language ?>">
	<head>
		<meta charset="UTF-8" />
		<meta name="viewport" content="initial-scale=1.0" />
		<?= FreshRSS_View::headStyle() ?>
		<script id="jsonVars" type="application/json">
<?php $this->renderHelper('javascript_vars'); ?>
		</script>
		<?= FreshRSS_View::headScript() ?>
		<link rel="shortcut icon" id="favicon" type="image/x-icon" sizes="16x16 64x64" href="<?= Minz_Url::display('/favicon.ico') ?>" />
		<link rel="icon msapplication-TileImage apple-touch-icon" type="image/png" sizes="256x256" href="<?= Minz_Url::display('/themes/icons/favicon-256.png') ?>" />
		<link rel="apple-touch-icon" href="<?= Minz_Url::display('/themes/icons/apple-touch-icon.png') ?>" />
		<meta name="apple-mobile-web-app-capable" content="yes" />
		<meta name="apple-mobile-web-app-status-bar-style" content="black" />
		<meta name="apple-mobile-web-app-title" content="<?= FreshRSS_Context::$system_conf->title ?>">
		<meta name="msapplication-TileColor" content="#FFF" />
		<meta name="referrer" content="never" />
		<meta name="robots" content="noindex,nofollow" />
		<?= FreshRSS_View::headTitle() ?>
	</head>
	<body>

<?php flush(); ?>
<div class="app-layout app-layout-simple">
	<div class="header">
		<div class="item title">
			<a href="<?= _url('index', 'index') ?>">
				<?php if (FreshRSS_Context::$system_conf->logo_html == '') { ?>
					<img class="logo" src="<?= _i('FreshRSS-logo', FreshRSS_Themes::ICON_URL) ?>" alt="FreshRSS" loading="lazy" />
				<?php
					} else {
						echo FreshRSS_Context::$system_conf->logo_html;
					}
				?>
			</a>
		</div>

		<div class="item"></div>

		<div class="item">
			<?php if (FreshRSS_Auth::accessNeedsAction()) { ?>
				<a class="signout" href="<?= _url('auth', 'logout') ?>">
					<?= _i('logout') . _t('gen.auth.logout') ?>
					(<?= htmlspecialchars(Minz_Session::param('currentUser', '_'), ENT_NOQUOTES, 'UTF-8') ?>)
				</a>
			<?php } ?>
		</div>
	</div>

	<?php $this->render(); ?>
</div>

<?php
	$msg = '';
	$status = 'closed';
	if (!empty($this->notification)) {
		$msg = $this->notification['content'];
		$status = $this->notification['type'];
		invalidateHttpCache();
	}
?>
<div id="notification" class="notification <?= $status ?>">
	<span class="msg"><?= $msg ?></span>
	<a class="close" href=""><?= _i('close') ?></a>
</div>

	</body>
</html>
