@font-face {
	font-family: "lato";
	font-style: normal;
	font-stretch: normal;
	font-weight: 400;
	src: url("../fonts/LatoLatin-Regular.woff") format("woff");
}

@font-face {
	font-family: "lato";
	font-style: italic;
	font-stretch: normal;
	font-weight: 400;
	src: url("../fonts/LatoLatin-Italic.woff") format("woff");
}

@font-face {
	font-family: "lato";
	font-style: normal;
	font-stretch: normal;
	font-weight: 700;
	src: url("../fonts/LatoLatin-Bold.woff") format("woff");
}

@font-face {
	font-family: "lato";
	font-style: italic;
	font-stretch: normal;
	font-weight: 700;
	src: url("../fonts/LatoLatin-BoldItalic.woff") format("woff");
}

@font-face {
	font-family: "spectral";
	font-style: normal;
	font-stretch: normal;
	font-weight: 400;
	src: url("../fonts/Spectral-Regular.woff") format("woff");
}

@font-face {
	font-family: "spectral";
	font-style: italic;
	font-stretch: normal;
	font-weight: 400;
	src: url("../fonts/Spectral-Italic.woff") format("woff");
}

@font-face {
	font-family: "spectral";
	font-style: normal;
	font-stretch: normal;
	font-weight: 700;
	src: url("../fonts/Spectral-Bold.woff") format("woff");
}

@font-face {
	font-family: "spectral";
	font-style: italic;
	font-stretch: normal;
	font-weight: 700;
	src: url("../fonts/Spectral-BoldItalic.woff") format("woff");
}
