@use "variables";

/*=== Tables */
table {
	border-collapse: collapse;
}

th, td {
	border: 1px solid variables.$grey-medium-light;
}

th {
	background: variables.$grey-lighter;
}

form td,
form th {
	font-weight: normal;
	text-align: center;
}
