<nav>
	<ul id="nav_entries">
		<li class="item"><a class="previous_entry" href="#"><?= _i('prev') ?></a></li>
		<li class="item"><a class="up" href="#"><?= _i('up') ?></a></li>
		<li class="item"><a class="next_entry" href="#"><?= _i('next') ?></a></li>
	</ul>
</nav>
