<?php

namespace marienfressinaud\LibOpml;

/**
 * A simple Exception class which represents any kind of OPML problem.
 * Message precises the current problem.
 *
 * @author Marien Fressinaud <dev@marienfressinaud.fr>
 * @link https://framagit.org/marienfressinaud/lib_opml
 * @license MIT
 */
class Exception extends \Exception
{
}
