@charset "UTF-8";

/*=== GENERAL */
/*============*/
html, body {
	background: #1c1c1c;
	color: #888;
	font-family: "OpenSans", "Cantarell", "Helvetica", "Arial", "PingFang SC", "Microsoft YaHei", sans-serif;
}

/*=== Links */
a, button.as-link {
	color: #6986b2;
	outline: none;
}

/*=== Images */
img.favicon {
	background: #fff;
	border-radius: 2px;
}

body img,
body video,
p.help .icon {
	filter: brightness(.6) contrast(1.2);
}

/*=== Forms */
legend {
	margin: 20px 0 5px;
	padding: 5px 0;
	font-size: 1.4em;
	border-bottom: 1px solid #2f2f2f;
}

label {
	min-height: 25px;
	padding: 5px 0;
	cursor: pointer;
}

textarea {
	width: 360px;
	height: 100px;
}

input, select, textarea {
	padding: 5px;
	background: #333;
	color: #999;
	border: 1px solid #000;
	border-radius: 3px;
	box-shadow: 0 2px 2px #1d1d1d inset;
	min-height: 25px;
	line-height: 25px;
	vertical-align: middle;
}

option {
	padding: 0 .5em;
}

input:focus, select:focus, textarea:focus {
	color: #6986b2;
	border-color: #2f2f2f;
}

input:invalid, select:invalid {
	border-color: #f00;
	box-shadow: 0 0 2px 1px #f00;
}

input:disabled, select:disabled {
	background-color: #222;
	color: #aaa;
	border-style: solid;
	border-color: #000;
}

/*=== Tables */
table {
	border-collapse: collapse;
}

th, td {
	border: 1px solid #333;
}

th {
	background: #222;
}

form td,
form th {
	font-weight: normal;
	text-align: center;
}

/*=== COMPONENTS */
/*===============*/
/*=== Forms */
.form-group.form-actions {
	padding: 5px 0;
	background: #1a1a1a;
	border-top: 1px solid #2f2f2f;
}

.form-group.form-actions .btn {
	margin: 0 10px;
}

.form-group .group-name {
	padding: 10px 0;
}

.form-group .group-controls {
	min-height: 25px;
	padding: 5px 0;
}

/*=== Buttons */
button.as-link[disabled] {
	color: #445 !important;
}

.stick input,
.stick .btn {
	border-radius: 0;
}

.stick .btn:first-child,
.stick input:first-child {
	border-radius: 0 3px 3px 0;
}

.stick .btn-important:first-child {
	border-left: 1px solid #000;
}

.stick .btn:last-child,
.stick input:last-child {
	border-radius: 3px 0 0 3px;
}

.stick .btn + .btn,
.stick .btn + input,
.stick .btn + .dropdown > .btn,
.stick input + .btn,
.stick input + input,
.stick input + .dropdown > .btn,
.stick .dropdown + .btn,
.stick .dropdown + input,
.stick .dropdown + .dropdown > .btn {
	border-right: none;
}

.stick input:focus+input {
	border-right: 1px solid #000;
}

.stick input+input:focus {
	border-right: 1px solid #333;
}

.stick .btn + .dropdown > .btn {
	border-right: none;
	border-radius: 3px 0 0 3px;
}

.btn {
	margin: 0;
	padding: 5px 10px;
	background: #111;
	display: inline-block;
	color: #888;
	font-size: 0.9rem;
	border: 1px solid #000;
	border-radius: 3px;
	min-height: 37px;
	min-width: 15px;
	line-height: 25px;
	vertical-align: middle;
	cursor: pointer;
	overflow: hidden;
}

a.btn {
	min-height: 25px;
	line-height: 25px;
}

.btn:hover {
	text-decoration: none;
	background: linear-gradient(to top, #4a5d7a 0%, #26303f 100%);
}

.btn:hover .icon {
	filter: brightness(1);
}

.btn.active,
.dropdown-target:target ~ .btn.dropdown-toggle {
	background: #333;
}

.btn.active .icon,
.dropdown-target:target ~ .btn.dropdown-toggle .icon {
	filter: brightness(1);
}

.btn:active {
	background: #26303f;
}

.btn-important {
	font-weight: normal;
	background: #26303f;
}

.btn-important:hover {
	background: linear-gradient(to top, #4a5d7a 0%, #26303f 100%);
}

.btn-important:active {
	background: #26303f;
}

.btn-important .icon {
	filter: brightness(1);
}

.btn-attention {
	background: #801;
}

.btn-attention:hover {
	background: linear-gradient(to top, #c04 0%, #801 100%);
}

.btn-attention:active {
	background: #801;
}

/*=== switches */
.switch {
	background-color: #333;
}

.switch.active {
	background-color: #6986b2;
}

.switch::before,
.switch:hover::before {
	background-color: black;
}

/*=== Navigation */
.nav-list {
	font-size: 0.9rem;
}

.nav-list .item,
.nav-list .item.nav-header {
	min-height: 2.5em;
	line-height: 2.5;
}

.nav-list .item a:hover {
	background: #26303f;
}

.nav-list .item.active {
	background: #333;
}

.nav-list .item:hover a,
.nav-list .item.active a {
	color: #888;
}

.nav-list .item > a {
	padding: 0 1rem;
}

.nav-list a:hover {
	text-decoration: none;
}

.nav-list .nav-header {
	padding: 0 1rem;
	font-weight: bold;
	background: #111;
	border-bottom: 1px solid #333;
}

.nav-list .nav-form {
	padding: 3px;
	text-align: center;
}

/*=== Dropdown */
.dropdown-menu {
	margin: 5px 0 0;
	padding: 5px 0;
	background: #1a1a1a;
	font-size: 0.8rem;
	border: 1px solid #888;
	border-radius: 5px;
	text-align: right;
}

.dropdown-menu::after {
	border-color: #888;
}

.dropdown-header,
.dropdown-section .dropdown-section-title {
	padding: 0.25rem 1rem 0.25rem 0.5rem;
	font-weight: bold;
	text-align: right;
	color: #888;
}

.dropdown-menu .item > a,
.dropdown-menu .item > span,
.dropdown-menu .item > .as-link {
	padding: 0 22px;
	line-height: 2.5em;
	font-size: inherit;
}

.dropdown-menu .dropdown-section .item > a,
.dropdown-menu .dropdown-section .item > span,
.dropdown-menu .dropdown-section .item > .as-link {
	padding-right: 2rem;
}

.dropdown-menu .dropdown-section .item:last-child {
	margin-bottom: 0.5rem;
}

.dropdown-menu .item > a:hover,
.dropdown-menu .item > button:hover:not([disabled]),
.dropdown-menu .item > label:hover:not(.noHover) {
	background: #26303f;
	color: #888;
}

.dropdown-menu > .item[aria-checked="true"] > a::before {
	font-weight: bold;
	margin: 0 -14px 0 0;
}

.dropdown-menu .input select,
.dropdown-menu .input input {
	margin: 0 auto 5px;
	padding: 2px 5px;
	border-radius: 3px;
}

.item ~ .dropdown-header,
.dropdown-section ~ .dropdown-section,
.item.separator {
	border-top-color: #333;
}

/*=== Alerts */
.alert {
	background: #111;
	color: #aaa;
	font-size: 0.9em;
	border: 1px solid #888;
	border-radius: 5px;
}

.alert-head {
	font-size: 1.15em;
}

.alert > a {
	text-decoration: underline;
	color: inherit;
}

.alert-warn {
	color: #c95;
	border: 1px solid #c95;
}

.alert-success {
	color: #484;
	border: 1px solid #484;
}

.alert-error {
	color: #a44;
	border: 1px solid #a44;
}

/*=== Pagination */
.pagination {
	background: #1c1c1c;
	color: #888;
}

.pagination .item a {
	color: #666;
}

.pagination:first-child .item {
	border-top: 1px solid #333;
	border-bottom: 1px solid #333;
}

#load_more.loading,
#load_more.loading:hover {
	background: url("loader.gif") center center no-repeat;
}

/*=== Boxes */
.box {
	border: 1px solid #000;
	border-radius: 5px;
}

.box .icon {
	filter: brightness(100%);
}

.box .box-title {
	margin: 0;
	padding: 5px 10px;
	background: #26303f;
	border-bottom: 1px solid #000;
	border-radius: 5px 5px 0 0;
}

.box .box-title .configure {
	margin-left: 4px;
}

.box .box-content {
	padding-right: 30px;
	max-height: 260px;
}

.box .box-content .item {
	font-size: 0.9rem;
	line-height: 2.5em;
}

/*=== Tree */
.tree {
	margin: 10px 0;
}

.tree-folder-title {
	padding: 0 10px;
	background: #1c1c1c;
	font-size: 1rem;
	position: relative;
	line-height: 2.5rem;
}

.tree-folder-title .title {
	background: inherit;
	color: #888;
}

.tree-folder-title .title:hover {
	text-decoration: none;
}

.tree-folder.active .tree-folder-title {
	background: #2c2c2c;
	font-weight: bold;
}

.tree-folder-items {
	background: #161616;
	border-top: 1px solid #222;
	border-bottom: 1px solid #222;
}

.tree-folder-items > .item {
	font-size: 0.8rem;
}

.tree-folder-items > .item.active {
	background: #1c1c1c;
}

.tree-folder-items > .item > a {
	text-decoration: none;
}

.tree-folder-items > .item.active > a {
	color: #888;
}

/*=== Scrollbar */

@supports (scrollbar-width: thin) {
	#sidebar {
		scrollbar-color: rgba(255, 255, 255, 0.05) rgba(0, 0, 0, 0.0);
	}

	#sidebar:hover {
		scrollbar-color: rgba(255, 255, 255, 0.3) rgba(0, 0, 0, 0.0);
	}
}

@supports not (scrollbar-width: thin) {
	#sidebar::-webkit-scrollbar-thumb {
		background: rgba(255, 255, 255, 0.1);
	}

	#sidebar:hover::-webkit-scrollbar-thumb {
		background: rgba(255, 255, 255, 0.3);
	}
}

/*=== STRUCTURE */
/*===============*/
/*=== Header */
.header > .item {
	vertical-align: middle;
	text-align: center;
	border-bottom: 1px solid #333;
}

.header > .item.title .logo {
	filter: grayscale(60%) brightness(1.1);
}

.header > .item.title a:hover .logo {
	filter: grayscale(60%) brightness(1.5);
}

.header > .item.search input {
	width: 350px;
}

.aside {
	background: #1c1c1c;
	border-left: 1px solid #333;
}

.aside.aside_feed {
	padding: 10px 0;
	text-align: center;
}

.aside.aside_feed .tree {
	margin: 10px 0 50px;
}

/*=== Aside main page (categories) */
.aside.aside_feed .category .title:not([data-unread="0"])::after {
	background-color: #171717;
}

.aside.aside_feed .feed .item-title:not([data-unread="0"])::after {
	background-color: #222;
	color: #888;
}

.aside.aside_feed .feed.active .item-title:not([data-unread="0"])::after {
	border-color: #888;
	color: #888;
}

/*=== Aside main page (feeds) */
.feed.item.empty.active {
	background: #c95;
}

.feed.item.error.active {
	background: #a44;
}

.feed.item.empty,
.feed.item.empty > a {
	color: #c95;
}

.feed.item.error,
.feed.item.error > a {
	color: #a44;
}

.feed.item.empty.active,
.feed.item.empty.active > a {
	color: #111;
}

.feed.item.error.active,
.feed.item.error.active > a {
	color: #fff;
}

.aside_feed .tree-folder-items .dropdown-menu::after {
	right: 2px;
}

.aside_feed .tree-folder-items .item .dropdown-target:target ~ .dropdown-toggle > .icon,
.aside_feed .tree-folder-items .item:hover .dropdown-toggle > .icon,
.aside_feed .tree-folder-items .item.active .dropdown-toggle > .icon {
	border-radius: 3px;
	background-color: #111;
}

/*=== Configuration pages */
.post {
	padding: 10px 50px;
	font-size: 0.9em;
}

.post form {
	margin: 10px 0;
}

.post.content {
	max-width: 550px;
}

/*=== Prompt (centered) */
.prompt .form-group {
	margin-bottom: 1rem;
}

.prompt .form-group::after {
	display: none;
}

.prompt .form-group.form-group-actions {
	display: flex;
	margin-top: 2rem;
	align-items: center;
	justify-content: space-between;
}

.prompt .btn.btn-important {
	padding-right: 1.5rem;
	padding-left: 1.5rem;
	font-size: 1.1rem;
}

/*=== New article notification */
#new-article {
	background: #26303f;
	font-size: 0.9em;
	text-align: center;
}

#new-article > a {
	line-height: 3em;
	font-weight: bold;
	color: #fff;
}

#new-article > a:hover {
	text-decoration: none;
	background: #4a5d7a;
}

/*=== Day indication */
.day {
	padding: 0 10px;
	font-weight: bold;
	line-height: 3em;
	border-top: 1px solid #333;
	border-bottom: 1px solid #333;
}

.day .name {
	padding: 0 0 0 10px;
	color: #aab;
	font-size: 1.8em;
	opacity: 0.3;
	font-style: italic;
	text-align: left;
	text-shadow: 0px -1px 0px #333;
}

/*=== Index menu */
.nav_menu {
	text-align: center;
	padding: 5px 0;
	border-bottom: 1px solid #2f2f2f;
}

/*=== Feed articles */
.flux {
	background: #1c1c1c;
	border-right: 2px solid #2f2f2f;
}

.flux .flux_header:hover {
	background: #111;
}

.flux.current {
	background: #111;
	border-right: 2px solid #0062be;
}

.flux.not_read {
	border-right: 2px solid #ff5300;
}

.flux.favorite {
	border-right: 2px solid #ffc300;
}


.flux_header {
	font-size: 0.8rem;
	cursor: pointer;
}

.flux_header .title {
	font-size: 0.9rem;
}

.flux_header .item.title a {
	color: #888;
}

.flux .item.date {
	color: #666;
	font-size: 0.7rem;
}

.flux:not(.current):hover .item.title {
	background: #111;
}

.flux .bottom {
	font-size: 0.8rem;
	text-align: center;
}

/*=== Content of feed articles */
.content {
	padding: 20px 10px;
}

.content > h1.title > a {
	color: #888;
}

.content hr {
	margin: 30px 10px;
	background: #666;
	height: 1px;
	border: 0;
	box-shadow: 0 2px 5px #666;
}

.content pre {
	margin: 10px auto;
	padding: 10px 20px;
	background: #222;
	color: #fff;
	font-size: 0.9rem;
	border: 1px solid #000;
	border-radius: 3px;
	overflow: auto;
}

.content code {
	padding: 2px 5px;
	background: #000;
	color: #d14;
	border: 1px solid #333;
	border-radius: 3px;
}

.content pre code {
	background: transparent;
	color: #fff;
	border: none;
}

.content blockquote {
	margin: 0;
	padding: 5px 20px;
	background: #222;
	display: block;
	color: #999;
	border-top: 1px solid #444;
	border-bottom: 1px solid #444;
}

.content blockquote p {
	margin: 0;
}

/*=== Notification and actualize notification */
.notification {
	background: #111;
	color: #c95;
	font-size: 0.9em;
	border: 1px solid #c95;
	border-radius: 5px;
	box-shadow: 0 0 5px #666;
	text-align: center;
	font-weight: bold;
	vertical-align: middle;
}

.notification.good {
	border-color: #484;
	color: #484;
}

.notification.bad {
	border-color: #a44;
	color: #a44;
}

.notification a.close:hover {
	background: #222;
	border-radius: 3px 0 0 3px;
}

.notification.good a.close:hover {
	background: #484;
}

.notification.bad a.close:hover {
	background: #a44;
}

/*=== "Load more" part */
#bigMarkAsRead {
	text-align: center;
	text-decoration: none;
}

#bigMarkAsRead:hover {
	background: #111;
	color: #aaa;
}

/*=== Navigation menu (for articles) */
#nav_entries {
	margin: 0;
	text-align: center;
	line-height: 3em;
	table-layout: fixed;
	background: #111;
	border-top: 1px solid #333;
}

/*=== READER VIEW */
/*================*/
#stream.reader .flux {
	background: #1c1c1c;
	border: none;
}

#stream.reader .flux .content {
	background-color: #111;
	border: none;
}

#stream.reader .flux .author {
	margin: 0 0 10px;
	color: #666;
	font-size: 90%;
}

/*=== GLOBAL VIEW */
/*================*/
.box.category .box-title .title {
	font-weight: normal;
	text-decoration: none;
	text-align: right;
	color: #888;
}

.box.category:not([data-unread="0"]) .box-title {
	background: #34495e;
}

.box.category:not([data-unread="0"]) .box-title:active {
	background: #26303f;
}

.box.category:not([data-unread="0"]) .box-title .title {
	color: #fff;
	font-weight: bold;
}

.box.category .title:not([data-unread="0"])::after {
	background: none;
	border: 0;
	position: absolute;
	top: 5px; left: 10px;
	font-weight: bold;
	box-shadow: none;
	text-shadow: none;
}

#stream.global .feed .item-title:not([data-unread="0"])::after {
	background-color: #171717;
	margin-top: 1rem;
}

/*=== Panel */
#panel {
	background: #1c1c1c;
	border: 1px solid #666;
	border-radius: 3px;
}

/*=== Slider */
#slider {
	background-color: #1c1c1c;
	border-right: 1px solid #666;
}

.properties {
	color: #111;
}

/*=== DIVERS */
/*===========*/
.aside.aside_feed .nav-form input,
.aside.aside_feed .nav-form select {
	width: 140px;
}

.aside.aside_feed .nav-form .dropdown .dropdown-menu {
	left: -20px;
}

.aside.aside_feed .nav-form .dropdown .dropdown-menu::after {
	left: 33px;
}

/*=== STATISTICS */
/*===============*/
.stat {
	margin: 10px 0 20px;
}

.stat th,
.stat td,
.stat tr {
	border: none;
}

.stat > table td,
.stat > table th {
	border-bottom: 1px solid #333;
}

/*=== MOBILE */
/*===========*/

@media (max-width: 840px) {
	.form-group .group-name {
		padding-bottom: 0;
	}

	.aside {
		transition: width 200ms linear;
	}

	.aside .toggle_aside,
	#panel .close,
	.dropdown-menu .toggle_aside {
		background: #111;
		border-bottom: 1px solid #333;
	}

	.aside.aside_feed {
		padding: 0;
	}

	.nav_menu .btn {
		margin: 5px 10px;
	}

	.nav_menu .stick {
		margin: 0 10px;
	}

	.nav_menu .stick .btn {
		margin: 5px 0;
	}

	.dropdown-target:target ~ .dropdown-toggle::after {
		background-color: #1a1a1a;
		border-top: 1px solid #888;
		border-right: 1px solid #888;
		left: 12px;
	}

	.day .name {
		font-size: 1.1rem;
	}

	.notification {
		border-top: none;
		border-left: none;
		border-right: none;
		border-radius: 0;
	}

	.notification a.close {
		display: block;
		right: 0;
	}

	.notification a.close:hover {
		opacity: 0.5;
	}

	.notification a.close .icon {
		display: none;
	}

	.post {
		padding-right: 15px;
		padding-left: 15px;
	}

	#close-slider.active {
		background: #111;
		border-bottom: 1px solid #333;
	}
}
